@@ -19,6 +19,8 @@ test_that("Route frequencies (headways)", {
   # TODO rewrite with synthesized sample data
   routes_frequency <- get_route_frequency(gtfs_duke)
   expect_equal(routes_frequency[routes_frequency$route_id == 1679, ]$median_headways, 24*60)
+  
+  expect_equal(nrow(get_route_frequency(gtfs_duke, service_ids = "none")), 0)
 })
 
 test_that("Route frequencies (headways) w/ service id", {
@@ -26,12 +28,8 @@ test_that("Route frequencies (headways) w/ service id", {
   routes_frequency <- get_route_frequency(gtfs_duke, service_ids = "c_883_b_21967_d_31")
   expect_equal(routes_frequency[routes_frequency$route_id == 1680, ]$median_headways, (53+1/3)*60)
 
-  expect_error(get_route_frequency(gtfs_duke, service_ids = "unknown"), 
-                 "Failed to calculate frequency, no departures found")
-  
   gtfs_duke2 = gtfs_duke
   gtfs_duke2$frequencies[1,] <- list("t_674449_b_19828_tn_21", "00:00:00", "23:00:00", 60, 0)
   expect_message(get_route_frequency(gtfs_duke2, service_ids = "c_883_b_21967_d_31"), 
-                 "A pre-calculated frequencies dataframe exists for this feed already, consider using that.")
-  
+                 "This feed already contains a pre-calculated frequencies data.frame, consider using that.")
 })
